
# geoplanar
Planar enforcement for polygon geoseries

![mexico-us](https://i.imgur.com/CFgnecL.png)


`geoplanar` supports the detection and correction of violations of [planar enforcement](https://ibis.geog.ubc.ca/courses/klink/gis.notes/ncgia/u12.html#SEC12.6) for polygon geoseries including:


- [missing holes](https://github.com/sjsrey/geoplanar/blob/main/notebooks/holes.ipynb)
- [nonplanar coincident edges](https://github.com/sjsrey/geoplanar/blob/main/notebooks/nonplanaredges.ipynb)
- [nonplanar touches](https://github.com/sjsrey/geoplanar/blob/main/notebooks/nonplanartouches.ipynb)
- [overlaps](https://github.com/sjsrey/geoplanar/blob/main/notebooks/overlaps.ipynb)
- [slivers](https://github.com/sjsrey/geoplanar/blob/main/notebooks/slivers.ipynb)


## Status

`geoplanar` is currently in alpha status and is open to contributions that help shape the scope of the package. It is being developed in support of  [research ](https://nsf.gov/awardsearch/showAward?AWD_ID=1759746&HistoricalAwards=false) and is likely to be undergoing changes as the project evolves.


## Funding

`geoplanar` is partially supported by [NSF Award #1759746, Comparative Regional Inequality Dynamics: Multiscalar and Multinational Perspectives](https://nsf.gov/awardsearch/showAward?AWD_ID=1759746&HistoricalAwards=false)


